@@ -7,21 +7,14 @@
 #include <sys/syscall.h>
 #include <sys/mman.h>
 #include <unistd.h>
-#include <asm/page.h>		/* For PAGE_SHIFT */
 #include <bitsize.h>
-
-/*
- * MMAP2_SHIFT is definitely *NOT* equal to getpageshift() for
- * many 32-bit architectures.  Supposedly this is fixed to 12
- * for all 32-bit architectures.  CHECK THIS!!!
- */
-# define MMAP2_SHIFT	12	/* Fixed by syscall definition */
+#include <klibc/sysconfig.h>
 
 /*
  * Set in SYSCALLS whether or not we should use an unadorned mmap() system
  * call (typical on 64-bit architectures).
  */
-#if (_BITSIZE == 32 && defined(__NR_mmap2)) || (_BITSIZE == 64 && !defined(__NR_mmap))
+#if !_KLIBC_NO_MMU && _KLIBC_USE_MMAP2
 
 /* This architecture uses mmap2(). The Linux mmap2() system call takes
    a page offset as the offset argument.  We need to make sure we have
@@ -31,8 +24,8 @@ extern void *__mmap2(void *, size_t, int, int, int, size_t);
 
 void *mmap(void *start, size_t length, int prot, int flags, int fd, off_t offset)
 {
-  const int mmap2_shift = MMAP2_SHIFT;
-  const unsigned long mmap2_mask = (1UL << mmap2_shift) - 1;
+  const int mmap2_shift = _KLIBC_MMAP2_SHIFT;
+  const off_t mmap2_mask = ((off_t)1 << mmap2_shift) - 1;
 
   if ( offset & mmap2_mask ) {
     errno = EINVAL;
@@ -43,7 +36,3 @@ void *mmap(void *start, size_t length, int prot, int flags, int fd, off_t offset
 }
 
 #endif
-
-
-    
-  
